/* NWERC'11 solution for random storage
 * Author: Jaap Eldering
 */

#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <iostream>
#include <sstream>
#include <vector>
#include <string>
#include <algorithm>

using namespace std;

typedef long long coord;

const double EPS = 1E-8;

class point {
public:
	coord x, y;

	point() { x = y = 0; }
	point(coord x1, coord y1) { x = x1; y = y1; }

	friend ostream &operator <<(ostream &os, point p);

	string str()
	{
		ostringstream res;
		res << *this;
		return res.str();
	}

	point operator +=(point a) { x += a.x; y += a.y; return *this; }
	point operator -=(point a) { x -= a.x; y -= a.y; return *this; }
};

point operator +(point a, point b) { return a += b; }
point operator -(point a, point b) { return a -= b; }
coord operator *(point a, point b) { return a.x*b.x + a.y*b.y; }

coord cross(point a, point b) { return a.x*b.y - a.y*b.x; }
double length(point a) { return sqrt((double)(a*a)); }

class line {
public:
	point p1, p2;

	line() { p1 = p2 = point(); }
	line(point q1, point q2) { p1 = q1; p2 = q2; }
};

ostream &operator <<(ostream &os, point p)  { return os << '(' << p.x << ',' << p.y << ')'; }

long long sgn(long long x) { return x==0 ? 0 : (x<0 ? -1 : 1); }

int intersect(line a, line b)
{
	// directions of lines
	point da = a.p2 - a.p1;
	point db = b.p2 - b.p1;

	// degenerate lines
	if ( length(da)<EPS )
		return cross(db,a.p1-b.p1)==0 && (a.p1-b.p1)*(a.p1-b.p2)<=0;
	if ( length(db)<EPS )
		return cross(da,b.p1-a.p1)==0 && (b.p1-a.p1)*(b.p1-a.p2)<=0;

	// special case parallel lines
	if ( cross(da,db)==0 ) {
		if ( cross(a.p1-b.p1,da)!=0 ) return 0;
		return ((b.p1-a.p1)*(b.p1-a.p2)<=0 ||
		        (b.p2-a.p1)*(b.p2-a.p2)<=0 ||
		        (a.p1-b.p1)*(a.p1-b.p2)<=0 ||
		        (a.p2-b.p1)*(a.p2-b.p2)<=0);
	}

	// return false if line segments not really cross
	if ( sgn(cross(da,b.p1-a.p1))*sgn(cross(da,b.p2-a.p1))>0 ) return 0;
	if ( sgn(cross(db,a.p1-b.p1))*sgn(cross(db,a.p2-b.p1))>0 ) return 0;

	return 1;
}

const size_t branchlimit = 10;

class quadtree {
private:
	point mid;
	coord len;
	vector<point> data;
	int branched;
	quadtree* branches[4];

public:
	quadtree(point _mid=point(), coord _len=(1<<14)):
		mid(_mid), len(_len), data(), branched(0) {}

	~quadtree() { clear(); }

	void clear()
	{
		data.clear();
		if ( branched ) {
			for(size_t i=0; i<4; i++) delete branches[i];
			branched = 0;
		}
	}

	void insert(const point &p)
	{
//		cerr << "insert " << p << " in " << mid << " " << len << endl;
		if ( !branched ) {
			data.push_back(p);
			if ( data.size()>branchlimit ) branch();
		} else {
			size_t i = ( p.x<mid.x ? 0 : 1 ) + ( p.y<mid.y ? 0 : 2);
//			cerr << "insert subtree " << i << endl;
			branches[i]->insert(p);
		}
	}

	vector<point> find(const point &p, double dist) const
	{
		vector<point> res;
		find_int(p,dist,res);
		return res;
	}

private:
	void branch()
	{
		if ( branched ) return;
		branched = 1;
//		cerr << "branching " << mid << " " << len << endl;
		for(size_t i=0; i<4; i++) {
			coord len2 = len/2;
			point mid2 = mid;
			mid2.x += ( i&1 ? len2 : -len2 );
			mid2.y += ( i&2 ? len2 : -len2 );
			branches[i] = new quadtree(mid2,len2);
		}
//		cerr << "created subtrees\n";
		for(size_t i=0; i<data.size(); i++) insert(data[i]);
		data.clear();
//		cerr << "data transferred\n";
	}

	void find_int(const point &p, double dist, vector<point> &res) const
	{
//		cerr << "find " << p << " in " << mid << " " << len << endl;
		if ( !branched ) {
//			cerr << "looking at " << data.size() << endl;
			for(size_t i=0; i<data.size(); i++) {
				if ( length(p-data[i])<=dist ) res.push_back(data[i]);
			}
		} else {
			for(size_t i=0; i<4; i++) {
//				cerr << "trying to find " << p << " in " << mid << " part " << i << endl;
				if ( ((!(i&1) && p.x-dist< mid.x) ||
				      ( (i&1) && p.x+dist>=mid.x)) &&
				     ((!(i&2) && p.y-dist< mid.y) ||
				      ( (i&2) && p.y+dist>=mid.y)) )
					branches[i]->find_int(p,dist,res);
			}
		}
	}
};

int operator <(point a, point b)
{
	if ( a.x!=b.x ) return a.x<b.x;
	return a.y<b.y;
}

int r;
quadtree sensors;
vector<point> products;
vector<line> walls;

int main()
{
	int nruns;

	cin >> nruns;
	for(int run=1; run<=nruns; run++) {

		int s,h,p;
		cin >> s >> r >> h >> p;
		sensors.clear();
		walls.resize(h);
		products.resize(p);

		for(int i=0; i<s; i++) {
			point tmp;
			cin >> tmp.x >> tmp.y;
			sensors.insert(tmp);
		}
		for(int i=0; i<h; i++) {
			cin >> walls[i].p1.x >> walls[i].p1.y
			    >> walls[i].p2.x >> walls[i].p2.y;
		}
		for(int i=0; i<p; i++) {
			point p;
			cin >> p.x >> p.y;

			vector<point> sr = sensors.find(p,r+1);

			for(size_t i=0; i<sr.size(); i++) {
				line l(p,sr[i]);
				int nsect = 0;
				for(size_t j=0; j<walls.size(); j++) {
					if ( intersect(l,walls[j]) ) nsect++;
				}
				if ( length(p-sr[i])>r-nsect+EPS ) {
					sr.erase(sr.begin()+i); i--;
				}
			}

			sort(sr.begin(),sr.end());
			cout << sr.size();
			for(size_t i=0; i<sr.size(); i++) cout << ' ' << sr[i];
			cout << endl;
		}
	}

	return 0;
}
